@@ -9,7 +9,6 @@ int main(int argc, char *argv[])
     size_t i;
     const char *libdatadir;
     char conjFN[512], verbsFN[512];
-    char *lower_latin1;
 
     libdatadir = getenv("LIBDATADIR");
     if (libdatadir == NULL)
@@ -24,14 +23,12 @@ int main(int argc, char *argv[])
     {
         printf("deconjugator.c: demo of the C API of Verbiste\n");
         printf("Usage: deconjugator VERB\n");
-        printf("Note: this program expects Latin-1 and writes Latin-1.\n");
+        printf("Note: this program expects UTF-8 and writes UTF-8.\n");
         return EXIT_FAILURE;
     }
 
 
-    lower_latin1 = verbiste_tolower_latin1(argv[1]);
-    vec = verbiste_deconjugate(lower_latin1);
-    verbiste_free_string(lower_latin1);
+    vec = verbiste_deconjugate(argv[1]);
 
     if (vec == NULL)
     {
