@@ -1,4 +1,4 @@
-/*  $Id: Command.cpp,v 1.19 2010/07/04 05:49:50 sarrazip Exp $
+/*  $Id: Command.cpp,v 1.21 2011/01/25 02:29:43 sarrazip Exp $
     Command.cpp - Abstract command-line driver
 
     verbiste - French conjugation system
@@ -34,12 +34,10 @@ namespace verbiste {
 
 Command::Command(const string &conjugationFilename,
                  const string &verbsFilename,
-                 const string &languageCode,
-                 bool _utf8Mode) throw (logic_error)
-  : fvd(new FrenchVerbDictionary(conjugationFilename, verbsFilename, false, languageCode)),
+                 FrenchVerbDictionary::Language _lang) throw (logic_error)
+  : fvd(new FrenchVerbDictionary(conjugationFilename, verbsFilename, false, _lang)),
                 // command-line tools do not tolerate missing accents
-    utf8Mode(_utf8Mode),
-    langCode(languageCode)
+    lang(_lang)
 {
 }
 
@@ -80,25 +78,7 @@ Command::run(int argc, char *argv[]) throw()
             }
 
 
-            string latin1InputWord;
-            if (utf8Mode)
-            {
-                try
-                {
-                    latin1InputWord = fvd->utf8ToLatin1(inputWord);
-                }
-                catch (int)
-                {
-                    // Conversion failed. Leave latin1InputWord empty.
-                }
-            }
-            else
-            {
-                // Source is assumed to be in ISO-8859-1:
-                latin1InputWord = inputWord;
-            }
-
-            processInputWord(fvd->tolowerLatin1(latin1InputWord));
+            processInputWord(inputWord);
         }
     }
     catch (const exception &e)
@@ -136,12 +116,8 @@ int Command::listAllInfinitives(std::ostream &out) const
 
     for (VerbTable::const_iterator it = fvd->beginKnownVerbs();
                                   it != fvd->endKnownVerbs(); ++it)
-    {
-        string inf = it->first;
-        if (utf8Mode)
-            inf = fvd->latin1ToUTF8(inf);
-        out << inf << '\n';
-    }
+        out << it->first << '\n';
+
     return EXIT_SUCCESS;
 }
 
