@@ -1,4 +1,4 @@
-/*  $Id: console-app.cpp,v 1.9 2010/07/04 05:49:51 sarrazip Exp $
+/*  $Id: console-app.cpp,v 1.11 2011/01/25 02:29:43 sarrazip Exp $
     console-app.cpp - Console application main function
 
     verbiste - French conjugation system
@@ -31,8 +31,6 @@
 using namespace std;
 
 
-
-
 class ConsoleApp
 {
 public:
@@ -45,29 +43,31 @@ public:
 
     void processCommand(const string &utf8Command)
     {
-        string lowerCaseLatin1UserText = fvd.tolowerLatin1(fvd.utf8ToLatin1(utf8Command));
+        string lowerCaseUTF8Command = fvd.wideToUTF8(
+                                        fvd.tolowerWide(
+                                          fvd.utf8ToWide(utf8Command)));
 
-        if (lowerCaseLatin1UserText == "/showpronouns" || lowerCaseLatin1UserText == "/sp")
+        if (lowerCaseUTF8Command == "/showpronouns" || lowerCaseUTF8Command == "/sp")
         {
             includePronouns = true;
             return;
         }
-        if (lowerCaseLatin1UserText == "/hidepronouns" || lowerCaseLatin1UserText == "/hp")
+        if (lowerCaseUTF8Command == "/hidepronouns" || lowerCaseUTF8Command == "/hp")
         {
             includePronouns = false;
             return;
         }
 
-        bool isItalian = (fvd.getLanguageCode() == "it");
+        bool isItalian = (fvd.getLanguage() == verbiste::FrenchVerbDictionary::ITALIAN);
 
         /*
             For each possible deconjugation, take the infinitive form and
             obtain its complete conjugation.
         */
         vector<InflectionDesc> v;
-        fvd.deconjugate(lowerCaseLatin1UserText, v);
+        fvd.deconjugate(lowerCaseUTF8Command, v);
 
-        string prevLatin1Infinitive;
+        string prevUTF8Infinitive;
         size_t numPages = 0;
 
         cout << "<result input='" << utf8Command << "'>\n";
@@ -77,31 +77,29 @@ public:
         {
             const InflectionDesc &d = *it;
 
-            VVVS latin1Conjug;
-            getConjugation(fvd, d.infinitive, d.templateName, latin1Conjug, includePronouns);
+            VVVS conjug;
+            getConjugation(fvd, d.infinitive, d.templateName, conjug, includePronouns);
 
-            if (latin1Conjug.size() == 0           // if no tenses
-                || latin1Conjug[0].size() == 0     // if no infinitive tense
-                || latin1Conjug[0][0].size() == 0  // if no person in inf. tense
-                || latin1Conjug[0][0][0].empty())  // if infinitive string empty
+            if (conjug.size() == 0           // if no tenses
+                || conjug[0].size() == 0     // if no infinitive tense
+                || conjug[0][0].size() == 0  // if no person in inf. tense
+                || conjug[0][0][0].empty())  // if infinitive string empty
             {
                 continue;
             }
 
-            string latin1Infinitive = latin1Conjug[0][0][0];
+            string utf8Infinitive = conjug[0][0][0];
 
-            if (latin1Infinitive == prevLatin1Infinitive)
+            if (utf8Infinitive == prevUTF8Infinitive)
                 continue;
 
-            cout << "<conjugation verb='" << fvd.latin1ToUTF8(latin1Infinitive) << "'>\n";
+            cout << "<conjugation verb='" << utf8Infinitive << "'>\n";
             numPages++;
 
             int i = 0;
-            for (VVVS::const_iterator t = latin1Conjug.begin();
-                                    t != latin1Conjug.end(); t++, i++)
+            for (VVVS::const_iterator t = conjug.begin();
+                                    t != conjug.end(); t++, i++)
             {
-                const VVS &latin1Tense = *t;
-
                 if (i == 1)
                     i = 4;
                 else if (i == 11)
@@ -115,14 +113,13 @@ public:
                 if (utf8TenseName.empty())
                     continue;
 
-                string latin1Persons = createTableCellText(
-                                                latin1Tense,
-                                                lowerCaseLatin1UserText,
+                string utf8Persons = createTableCellText(
+                                                fvd,
+                                                *t,
+                                                lowerCaseUTF8Command,
                                                 "*",
                                                 "");
 
-                string utf8Persons = fvd.latin1ToUTF8(latin1Persons);
-
                 cout << "<tense name='" << utf8TenseName << "'>\n";
                 cout << utf8Persons << "\n";
                 cout << "</tense>\n";
@@ -130,7 +127,7 @@ public:
 
             cout << "</conjugation>\n";
 
-            prevLatin1Infinitive = latin1Infinitive;
+            prevUTF8Infinitive = utf8Infinitive;
 
         }   // for
 
@@ -152,15 +149,22 @@ main(int /*argc*/, char * /*argv*/[])
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
-    verbiste::FrenchVerbDictionary *fvd;
+    using namespace verbiste;
+
+    FrenchVerbDictionary *fvd;
     try
     {
         const char *langCode = getenv("VERBISTE_LANG");
         if (langCode == NULL || langCode[0] == '\0')
             langCode = "fr";
         string conjFN, verbsFN;
-        verbiste::FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, langCode);
-        fvd = new verbiste::FrenchVerbDictionary(conjFN, verbsFN, true, langCode);  // may throw
+
+        FrenchVerbDictionary::Language lang = FrenchVerbDictionary::parseLanguageCode(langCode);
+        if (lang == FrenchVerbDictionary::NO_LANGUAGE)
+            lang = FrenchVerbDictionary::FRENCH;
+
+        FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, lang);
+        fvd = new FrenchVerbDictionary(conjFN, verbsFN, true, lang);  // may throw
     }
     catch(logic_error &e)
     {
