@@ -1,4 +1,4 @@
-/*  $Id: french-conjugator.cpp,v 1.26 2010/07/04 17:06:34 sarrazip Exp $
+/*  $Id: french-conjugator.cpp,v 1.30 2011/01/26 02:03:28 sarrazip Exp $
     french-conjugator.cpp - Conjugation of French verbs
 
     verbiste - French conjugation system
@@ -58,7 +58,6 @@ static struct option knownOptions[] =
     { "tense",          required_argument,      NULL, 't' },
     { "template",       required_argument,      NULL, 'e' },
     { "pronouns",       no_argument,            NULL, 'p' },
-    { "utf8",           no_argument,            NULL, 'u' },
     { "all-infinitives",no_argument,            NULL, 'i' },
 
     { NULL, 0, NULL, 0 }  // marks the end
@@ -72,9 +71,8 @@ public:
 
     ConjugatorCommand(const string &conjugationFilename,
                       const string &verbsFilename,
-                      const string &langCode,
-                      bool utf8Mode) throw(logic_error)
-      : Command(conjugationFilename, verbsFilename, langCode, utf8Mode),
+                      FrenchVerbDictionary::Language lang) throw(logic_error)
+      : Command(conjugationFilename, verbsFilename, lang),
         reqMode(INVALID_MODE),
         reqTense(INVALID_TENSE),
         reqTemplate(),
@@ -134,8 +132,8 @@ ConjugatorCommand::displayTense(FrenchVerbDictionary &fvd,
     typedef vector<VS> VVS;
 
     VVS conjug;
-    FrenchVerbDictionary::generateTense(radical, templ, mode, tense, conjug,
-                                        includePronouns, aspirateH, langCode == "it");
+    fvd.generateTense(radical, templ, mode, tense, conjug,
+                      includePronouns, aspirateH, lang == FrenchVerbDictionary::ITALIAN);
 
     for (VVS::const_iterator p = conjug.begin(); p != conjug.end(); p++)
     {
@@ -145,9 +143,6 @@ ConjugatorCommand::displayTense(FrenchVerbDictionary &fvd,
                 cout << ", ";
             string s = *i;
 
-            if (utf8Mode)
-                s = fvd.latin1ToUTF8(s);
-
             cout << s;
         }
         cout << "\n";
@@ -167,25 +162,47 @@ ConjugatorCommand::displayConjugation(FrenchVerbDictionary &fvd,
 
         string radical = FrenchVerbDictionary::getRadical(infinitive, tname);
 
-        displayTense(fvd, radical, templ, INFINITIVE_MODE, PRESENT_TENSE);
+        if (lang == FrenchVerbDictionary::FRENCH || lang == FrenchVerbDictionary::ITALIAN)
+        {
+            displayTense(fvd, radical, templ, INFINITIVE_MODE, PRESENT_TENSE);
 
-        displayTense(fvd, radical, templ, INDICATIVE_MODE, PRESENT_TENSE);
-        displayTense(fvd, radical, templ, INDICATIVE_MODE, IMPERFECT_TENSE);
-        displayTense(fvd, radical, templ, INDICATIVE_MODE, FUTURE_TENSE);
-        displayTense(fvd, radical, templ, INDICATIVE_MODE, PAST_TENSE);
+            displayTense(fvd, radical, templ, INDICATIVE_MODE, PRESENT_TENSE);
+            displayTense(fvd, radical, templ, INDICATIVE_MODE, IMPERFECT_TENSE);
+            displayTense(fvd, radical, templ, INDICATIVE_MODE, FUTURE_TENSE);
+            displayTense(fvd, radical, templ, INDICATIVE_MODE, PAST_TENSE);
 
-        displayTense(fvd, radical, templ, CONDITIONAL_MODE, PRESENT_TENSE);
+            displayTense(fvd, radical, templ, CONDITIONAL_MODE, PRESENT_TENSE);
 
-        displayTense(fvd, radical, templ, SUBJUNCTIVE_MODE, PRESENT_TENSE);
-        displayTense(fvd, radical, templ, SUBJUNCTIVE_MODE, IMPERFECT_TENSE);
+            displayTense(fvd, radical, templ, SUBJUNCTIVE_MODE, PRESENT_TENSE);
+            displayTense(fvd, radical, templ, SUBJUNCTIVE_MODE, IMPERFECT_TENSE);
 
-        displayTense(fvd, radical, templ, IMPERATIVE_MODE, PRESENT_TENSE);
+            displayTense(fvd, radical, templ, IMPERATIVE_MODE, PRESENT_TENSE);
 
-        displayTense(fvd, radical, templ, PARTICIPLE_MODE, PRESENT_TENSE);
-        displayTense(fvd, radical, templ, PARTICIPLE_MODE, PAST_TENSE);
-
-        if (langCode == "it")
+            displayTense(fvd, radical, templ, PARTICIPLE_MODE, PRESENT_TENSE);
+            displayTense(fvd, radical, templ, PARTICIPLE_MODE, PAST_TENSE);
+        }
+        if (lang == FrenchVerbDictionary::ITALIAN)
             displayTense(fvd, radical, templ, GERUND_MODE, PRESENT_TENSE);
+
+        if (lang == FrenchVerbDictionary::GREEK)
+        {
+            displayTense(fvd, radical, templ, PRESENT_INDICATIVE, ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PRESENT_INDICATIVE, PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PRESENT_SUBJUNCTIVE, ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PRESENT_SUBJUNCTIVE, PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PRESENT_IMPERATIVE, IMPERATIVE_ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PRESENT_IMPERATIVE, IMPERATIVE_PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PRESENT_GERUND, PRESENT_TENSE);
+            displayTense(fvd, radical, templ, PAST_IMPERFECT_INDICATIVE, ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_IMPERFECT_INDICATIVE, PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_INDICATIVE, ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_INDICATIVE, PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_SUBJUNCTIVE, ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_SUBJUNCTIVE, PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_IMPERATIVE, IMPERATIVE_ACTIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_IMPERATIVE, IMPERATIVE_PASSIVE_TENSE);
+            displayTense(fvd, radical, templ, PAST_PERFECT_INFINITIVE, PAST_PERFECT);
+        }
     }
     catch (logic_error &e)
     {
@@ -268,7 +285,6 @@ displayHelp()
 "--tense=T          Only display tense T (present, past, etc)\n"
 "--template=T       Use template T to conjugate the verbs\n"
 "--pronouns         Include pronouns in the displayed conjugation\n"
-"--utf8             Assume that the terminal uses UTF-8 instead of Latin-1\n"
 "--all-infinitives  Print the names of all known verbs, one per line (unsorted)\n"
 "\n"
 "See the " << commandName << "(1) manual page for details.\n"
@@ -283,9 +299,6 @@ int
 main(int argc, char *argv[])
 {
     setlocale(LC_CTYPE, "");
-    bool utf8Mode = (strcmp(nl_langinfo(CODESET), "UTF-8") == 0);
-        // See http://www.cl.cam.ac.uk/~mgk25/unicode.html
-        // re: "How should the UTF-8 mode be activated?"
 
     Mode reqMode = INVALID_MODE;
     Tense reqTense = INVALID_TENSE;
@@ -312,7 +325,7 @@ main(int argc, char *argv[])
 
                 case 'l':
                     langCode = optarg;
-                    if (langCode != "fr" && langCode != "it")
+                    if (FrenchVerbDictionary::parseLanguageCode(langCode) == FrenchVerbDictionary::NO_LANGUAGE)
                     {
                         cerr << commandName << ": invalid language code " << optarg << "\n";
                         return EXIT_FAILURE;
@@ -353,10 +366,6 @@ main(int argc, char *argv[])
                     displayHelp();
                     return EXIT_SUCCESS;
 
-                case 'u':
-                        utf8Mode = true;
-                    break;
-
                 case 'i':
                     listAllInfinitives = true;
                     break;
@@ -381,13 +390,14 @@ main(int argc, char *argv[])
 
     try
     {
-        if (langCode != "fr" && langCode != "it")
-            langCode = "fr";
+        FrenchVerbDictionary::Language lang = FrenchVerbDictionary::parseLanguageCode(langCode);
+        if (lang == FrenchVerbDictionary::NO_LANGUAGE)
+            lang = FrenchVerbDictionary::FRENCH;
 
         string conjFN, verbsFN;
-        FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, langCode);
+        FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, lang);
 
-        ConjugatorCommand cmd(conjFN, verbsFN, langCode, utf8Mode);
+        ConjugatorCommand cmd(conjFN, verbsFN, lang);
 
         if (listAllInfinitives)
             return cmd.listAllInfinitives(cout);
