@@ -1,4 +1,4 @@
-/*  $Id: panel-applet.cpp,v 1.14 2009/03/10 02:59:36 sarrazip Exp $
+/*  $Id: panel-applet.cpp,v 1.19 2010/06/22 01:48:51 sarrazip Exp $
     panel-applet.cpp - GNOME Panel applet main functions
 
     verbiste - French conjugation system
@@ -22,6 +22,7 @@
 
 #include "gtk/main-window.h"
 #include "gui/conjugation.h"
+#include "gtk/util.h"
 
 #include <panel-applet.h>
 
@@ -66,17 +67,17 @@ onKeyPressInEntry(GtkWidget *entry, GdkEventKey *event, gpointer)
 
     switch (event->keyval)
     {
-	case GDK_Return:
-	case GDK_KP_Enter:
-	    {
-		const gchar *text = gtk_entry_get_text(GTK_ENTRY(entry));
-		processText(text);
-		gtk_entry_set_text(GTK_ENTRY(entry), "");
-	    }
-	    return TRUE;
+        case GDK_Return:
+        case GDK_KP_Enter:
+            {
+                const gchar *text = gtk_entry_get_text(GTK_ENTRY(entry));
+                processText(text);
+                gtk_entry_set_text(GTK_ENTRY(entry), "");
+            }
+            return TRUE;
 
-	default:
-	    return FALSE;
+        default:
+            return FALSE;
     }
 }
 
@@ -84,11 +85,11 @@ onKeyPressInEntry(GtkWidget *entry, GdkEventKey *event, gpointer)
 static
 gboolean
 entry_button_press_event(GtkWidget * /*widget*/,
-			GdkEventButton *event,
-			gpointer *applet)
+                        GdkEventButton *event,
+                        gpointer *applet)
 {
     panel_applet_request_focus((PanelApplet *) applet, event->time);
-  
+
     /* We just wanted to insert the above function call before the
      * default action...
     */
@@ -98,9 +99,14 @@ entry_button_press_event(GtkWidget * /*widget*/,
 
 static const BonoboUIVerb applet_menu_verbs[] =
 {
-    BONOBO_UI_VERB("VerbisteAbout", onAbout),
-    BONOBO_UI_VERB("VerbisteEmptyTextField", onEmptyTextField),
-    BONOBO_UI_VERB_END
+    /*  Not using BONOBO_UI_VERB and BONOBO_UI_VERB_END because they
+        generate compiler warnings because they do not provide an
+        initializer for member BonoboUIVerb::dummy.
+        See libbonoboui-2.0/bonobo/bonobo-ui-component.h (version 2.24.1).
+    */
+    { "VerbisteAbout",          onAbout,          NULL, NULL },
+    { "VerbisteEmptyTextField", onEmptyTextField, NULL, NULL },
+    { NULL, NULL, NULL, NULL }
 };
 
 
@@ -109,10 +115,10 @@ gboolean
 appletFill(PanelApplet *applet, const gchar *iid, gpointer)
 {
     if (strcmp(iid, "OAFIID:GNOME_" PACKAGE) != 0)
-	return FALSE;
+        return FALSE;
 
     /*
-	Initialize the panel part of the applet interface.
+        Initialize the panel part of the applet interface.
     */
     GtkWidget *label = gtk_label_new(_("Verb:"));
 
@@ -120,10 +126,10 @@ appletFill(PanelApplet *applet, const gchar *iid, gpointer)
     gtk_entry_set_width_chars(GTK_ENTRY(appletEntry), 10);
 
     g_signal_connect(G_OBJECT(appletEntry), "key-press-event",
-			G_CALLBACK(onKeyPressInEntry), NULL);
-    
+                        G_CALLBACK(onKeyPressInEntry), NULL);
+
     g_signal_connect(G_OBJECT (appletEntry), "button_press_event",
-			G_CALLBACK(entry_button_press_event), applet);
+                        G_CALLBACK(entry_button_press_event), applet);
 
     GtkWidget *hbox = gtk_hbox_new(FALSE, 2);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -132,39 +138,35 @@ appletFill(PanelApplet *applet, const gchar *iid, gpointer)
     gtk_container_add(GTK_CONTAINER(applet), hbox);
 
     string applet_menu_xml = string() +
-	"<popup name=\"button3\">\n"
-	"    <menuitem\n"
-	"        name=\"Verbiste About Item\"\n"
-	"        verb=\"VerbisteAbout\"\n"
-	"        _label=\"" + _("_About...") + "\"\n"
-	"        pixtype=\"stock\"\n"
-	"        pixname=\"gnome-stock-about\"\n"
-	"        />\n"
-	"    <menuitem\n"
-	"        name=\"Verbiste Empty Text Field Item\"\n"
-	"        verb=\"VerbisteEmptyTextField\"\n"
-	"        _label=\"" + _("_Empty Text Field") + "\"\n"
-	"        pixtype=\"stock\"\n"
-	"        pixname=\"gnome-stock-erase\"\n"
-	"        />\n"
-	"</popup>\n"
-	;
+        "<popup name=\"button3\">\n"
+        "    <menuitem\n"
+        "        name=\"Verbiste About Item\"\n"
+        "        verb=\"VerbisteAbout\"\n"
+        "        _label=\"" + _("_About...") + "\"\n"
+        "        pixtype=\"stock\"\n"
+        "        pixname=\"gnome-stock-about\"\n"
+        "        />\n"
+        "    <menuitem\n"
+        "        name=\"Verbiste Empty Text Field Item\"\n"
+        "        verb=\"VerbisteEmptyTextField\"\n"
+        "        _label=\"" + _("_Empty Text Field") + "\"\n"
+        "        pixtype=\"stock\"\n"
+        "        pixname=\"gnome-stock-erase\"\n"
+        "        />\n"
+        "</popup>\n"
+        ;
 
 
     panel_applet_setup_menu(applet,
-			applet_menu_xml.c_str(), applet_menu_verbs, NULL);
+                        applet_menu_xml.c_str(), applet_menu_verbs, NULL);
 
     gtk_widget_show_all(GTK_WIDGET(applet));
 
-    try
+    string errorMsg = initDictPointers();
+    if (!errorMsg.empty())
     {
-	extern verbiste::FrenchVerbDictionary *fvd;
-	fvd = initVerbDict();
-    }
-    catch(logic_error &e)
-    {
-	gtk_widget_set_sensitive(appletEntry, false);
-	showErrorDialog(PACKAGE_FULL_NAME + string(": ") + e.what());
+        gtk_widget_set_sensitive(appletEntry, false);
+        showErrorDialog(PACKAGE_FULL_NAME + string(": ") + errorMsg);
     }
 
     return TRUE;
