@@ -1,4 +1,4 @@
-/*  $Id: gtk-app.cpp,v 1.3 2007/01/16 03:30:04 sarrazip Exp $
+/*  $Id: gtk-app.cpp,v 1.7 2010/06/22 01:48:51 sarrazip Exp $
     gtk-app.cpp - GTK+ application main function
 
     verbiste - French conjugation system
@@ -22,6 +22,7 @@
 
 #include "main-window.h"
 #include "gui/conjugation.h"
+#include "gtk/util.h"
 
 #include <stdlib.h>
 #include <locale.h>
@@ -106,25 +107,25 @@ main(int argc, char *argv[])
     int c;
     do
     {
-	c = getopt_long(argc, argv, "hv", knownOptions, NULL);
+        c = getopt_long(argc, argv, "hv", knownOptions, NULL);
 
-	switch (c)
-	{
-	    case EOF:
-		break;  // nothing to do
+        switch (c)
+        {
+            case EOF:
+                break;  // nothing to do
 
-	    case 'v':
-		displayVersionNo();
-		return EXIT_SUCCESS;
+            case 'v':
+                displayVersionNo();
+                return EXIT_SUCCESS;
 
-	    case 'h':
-		displayHelp();
-		return EXIT_SUCCESS;
+            case 'h':
+                displayHelp();
+                return EXIT_SUCCESS;
 
-	    default:
-		displayHelp();
-		return EXIT_FAILURE;
-	}
+            default:
+                displayHelp();
+                return EXIT_FAILURE;
+        }
     } while (c != EOF && c != '?');
 
     #endif  /* ndef HAVE_GETOPT_LONG */
@@ -133,15 +134,12 @@ main(int argc, char *argv[])
     gtk_init(&argc, &argv);
 
     hideOnDelete = FALSE;
-    try
+
+    string errorMsg = initDictPointers();
+    if (!errorMsg.empty())
     {
-	extern verbiste::FrenchVerbDictionary *fvd;
-	fvd = initVerbDict();
-    }
-    catch(logic_error &e)
-    {
-	showErrorDialog(PACKAGE_FULL_NAME + string(": ") + e.what());
-	return EXIT_FAILURE;
+        showErrorDialog(PACKAGE_FULL_NAME + string(": ") + errorMsg);
+        return EXIT_FAILURE;
     }
 
     processText("");  // force the result window to be initially displayed
