@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.cpp,v 1.50 2011/01/30 17:42:00 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.cpp,v 1.51 2012/04/24 02:46:05 sarrazip Exp $
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -27,6 +27,9 @@
 #include <errno.h>
 #include <string.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 using namespace std;
 using namespace verbiste;
@@ -347,6 +350,20 @@ FrenchVerbDictionary::init(const string &conjugationFilename,
     loadConjugationDatabase(conjugationFilename.c_str(), includeWithoutAccents);
     loadVerbDatabase(verbsFilename.c_str(), includeWithoutAccents);
 
+    // Load additional verbs from $HOME/.verbiste/verbs-<lang>.xml, if present.
+    //
+    const char *home = getenv("HOME");
+    if (home != NULL)  // do nothing if $HOME not defined
+    {
+        string otherVerbsFilename = string(home) + "/.verbiste/verbs-" + getLanguageCode(lang) + ".xml";
+        struct stat statbuf;
+        if (stat(otherVerbsFilename.c_str(), &statbuf) == 0)  // if file exists
+        {
+            //cout << "otherVerbsFilename=" << otherVerbsFilename << endl;
+            loadVerbDatabase(otherVerbsFilename.c_str(), includeWithoutAccents);
+        }
+    }
+
     if (trace)
         cout << "FrenchVerbDictionary::init: trie takes "
              << verbTrie.computeMemoryConsumption() << " bytes\n";
@@ -531,6 +548,9 @@ FrenchVerbDictionary::getUTF8XmlProp(xmlNodePtr node, const char *propName)
 }
 
 
+// Reads the given XML document and adds data to members knownVerbs,
+// aspirateHVerbs and verbTrie.
+//
 void
 FrenchVerbDictionary::readVerbs(xmlDocPtr doc,
                                 bool includeWithoutAccents)
@@ -651,7 +671,7 @@ FrenchVerbDictionary::readVerbs(xmlDocPtr doc,
 
 
 // String parameters expected to be in UTF-8.
-// Trie contains wide character strings.
+// Adds to 'verbTrie', which contains wide character strings.
 //
 void
 FrenchVerbDictionary::insertVerbRadicalInTrie(
