@@ -1,4 +1,4 @@
-/*  $Id: Trie.h,v 1.11 2010/05/16 00:17:18 sarrazip Exp $
+/*  $Id: Trie.h,v 1.15 2011/01/08 19:07:36 sarrazip Exp $
     Trie.h - Tree structure for string storage
 
     verbiste - French conjugation system
@@ -30,10 +30,9 @@
 namespace verbiste {
 
 
-/**
-    Tree structure for string storage.
-    @param        T        type of the user data attached to the stored strings;
-                            pointers to objects of type T will be stored in the
+/** Tree structure for (wide character) string storage.
+    @param        T     type of the user data attached to the stored strings;
+                        pointers to objects of type T will be stored in the
                         trie, but no T object will be created, copied,
                         assigned or destroyed by the trie.
 */
@@ -43,7 +42,7 @@ class Trie
 public:
 
     /** Constructs an empty trie.
-        @param        userDataFromNew                determines if the destructor
+        @param        userDataFromNew   determines if the destructor
                                         must assume that all "user data"
                                         pointers come from new and must
                                         thus be destroyed with delete
@@ -56,17 +55,26 @@ public:
     virtual ~Trie();
 
 
-    /** Adds the given key and associated it with the given user data pointer.
+    /** Adds the given (wide character) key and associates it with
+        the given user data pointer.
         @returns        the user data previously associated with the key,
                         or NULL is no user data was associated
     */
-    T *add(const std::string &key, T *userData);
+    T *add(const std::wstring &key, T *userData);
 
 
-    T *get(const std::string &key) const;
+    /** Searches the trie with the given (wide character) key.
+        Invokes the virtual function onFoundPrefixWithUserData()
+        for each find.
+        @param  key         wide character string to search for
+        @returns            a pointer to the user data pointer
+                            associated with 'key', or NULL if
+                            nothing was found
+    */
+    T *get(const std::wstring &key) const;
 
 
-    T *getWithDefault(const std::string &key, T *deFault = NULL);
+    T *getWithDefault(const std::wstring &key, T *deFault = NULL);
 
 
     /** Obtains the address of the user data associated with 'key'
@@ -75,24 +83,30 @@ public:
                         associated with 'key';
                         if a new entry was created, the T * is null.
     */
-    T **getUserDataPointer(const std::string &key);
+    T **getUserDataPointer(const std::wstring &key);
 
 
     /** Callback invoked by the Trie<>::get() method.
         This callback will be called for each prefix of the searched
         string for which the trie has some user data.
         This method does nothing if it is not overridden in a derived class.
-        @param        key                the searched string
-        @param        index                length of the prefix
-        @param        userData        user data that is associated with the prefix
+        @param  key         the searched string
+        @param  index       length of the prefix
+        @param  userData    user data that is associated with the prefix
     */
-    virtual void onFoundPrefixWithUserData(const std::string &/*key*/,
-                                        std::string::size_type /*index*/,
+    virtual void onFoundPrefixWithUserData(const std::wstring &/*key*/,
+                                        std::wstring::size_type /*index*/,
                                         const T * /*userData*/) const
                                                         throw()
     {
     }
 
+    /** Computes and returns the number of memory bytes consumed by
+        this object, excluding the size of the user data instances.
+        @returns                        number of bytes
+    */
+    size_t computeMemoryConsumption() const;
+
 private:
 
     class Row;
@@ -100,8 +114,7 @@ private:
     class Descriptor
     {
     public:
-        /*
-            Constructs a descriptor that can point to an inferior row.
+        /** Constructs a descriptor that can point to an inferior row.
             @param        inferior        pointer to the inferior row
                                             (may be NULL);
                                         this pointer must have been obtained
@@ -116,30 +129,40 @@ private:
             return *this;
         }
 
-        /*
-            Destroys this object and calls operator delete on the inferior row.
+        /** Destroys this object and calls operator delete on the inferior row.
             Does not call operator delete on userData.
         */
         ~Descriptor();
 
-        /*
-            Calls recursiveDelete() on *inferiorRow if inferiorRow is not NULL.
+        /** Calls recursiveDelete() on *inferiorRow if inferiorRow is not NULL.
             Then, calls operator delete that row and sets inferiorRow to NULL.
             @param        deleteUserData        if true, operator delete is called
                                             on userData (which may be NULL)
         */
         void recursiveDelete(bool deleteUserData);
 
+        /** Computes and returns the number of memory bytes consumed by
+            this object, excluding the size of the user data.
+            @returns                        number of bytes
+        */
+        size_t computeMemoryConsumption() const;
+
         Row *inferiorRow;
         T *userData;
     };
 
     struct CharDesc
     {
-        unsigned char c;
+        wchar_t unichar;  // Unicode character code
         Descriptor desc;
 
-        CharDesc(char cc) : c(static_cast<unsigned char>(cc)), desc() {}
+        CharDesc(wchar_t u) : unichar(u), desc() {}
+
+        /** Computes and returns the number of memory bytes consumed by
+            this object, excluding the size of the Descriptor's user data.
+            @returns                        number of bytes
+        */
+        size_t computeMemoryConsumption() const;
     };
 
     class Row
@@ -150,8 +173,7 @@ private:
         {
         }
 
-        /*
-            Calls recursiveDelete() on each Descriptor in this row.
+        /** Calls recursiveDelete() on each Descriptor in this row.
             Then empties this row.
             @param        deleteUserData        if true, operator delete is called
                                             on the userData field of the
@@ -160,18 +182,23 @@ private:
         void recursiveDelete(bool deleteUserData);
 
 
-        /*
-            Finds an element of this row whose character field is equal to 'c'.
-            Returns end() if no such element exists.
+        /** Finds an element of this row whose (wide) character field is
+            equal to 'unichar'.
+            Returns NULL if no such element exists.
         */
-        Descriptor *find(unsigned char c);
+        Descriptor *find(wchar_t unichar);
 
-        /*
-            Finds or creates an element of this row whose char. field is 'c'.
+        /** Finds or creates an element of this row whose char. field is 'unichar'.
             If no such element exists, one is created using the
             default constructor of the Descriptor class.
         */
-        Descriptor &operator [] (unsigned char c);
+        Descriptor &operator [] (wchar_t unichar);
+
+        /** Computes and returns the number of memory bytes consumed by
+            this object, excluding the size of the Descriptors' user data.
+            @returns                        number of bytes
+        */
+        size_t computeMemoryConsumption() const;
 
     private:
         std::vector<CharDesc> elements;  // average size should be about 1.4
@@ -179,8 +206,8 @@ private:
 
 
     Descriptor *getDesc(Row *row,
-                        const std::string &key,
-                        std::string::size_type index,
+                        const std::wstring &key,
+                        std::wstring::size_type index,
                         bool create,
                         bool callFoundPrefixCallback);
 
